Datasets included with the package for demos, vignettes, and tests. Unless otherwise noted, they correspond to the **Huancane River basin (Peru)**.
Source:R/datasets.R
example_basin_datasets.RdDatasets included with the package for demos, vignettes, and tests. Unless otherwise noted, they correspond to the **Huancane River basin (Peru)**.
Included objects
- gridded_climate_netcdfs: NetCDF precipitation and temperature (daily).
- swat_txtinout_data: SWAT TxtInOut inputs as a named list.
- subs1: Subbasins (sf polygons).
- riv1: River network (sf lines).
- qobserved: Daily streamflow at the outlet gauge.
See also
Other Data:
gridded_climate_netcdfs,
qobserved,
riv1,
subs1,
swat_txtinout_data