Returns a list of SWAT output variables by category (reach, subbasin, or HRU), or all combined. Useful for filtering when reading SWAT output files.
Usage
get_swat_vars(type = c("all", "rch", "sub", "hru"))Value
A character vector of variable names for the selected category. If
"all" is selected, a list of vectors for each category is returned.
See also
Other Output readers:
output_hru(),
output_rch(),
output_sub(),
read_pcp(),
read_tmp()